..
    :copyright: Copyright (c) 2013 Martin Pengelly-Phillips
    :license: See LICENSE.txt.

######
Clique
######

Manage collections with common numerical component.

.. toctree::
    :maxdepth: 1

    introduction
    installing
    tutorial
    assembly
    collection
    api_reference/index
    release/index
    license
    glossary

******************
Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

